@@ -10,14 +10,13 @@ from sk_transformers.utils import check_ready_to_transform
 
 
 class DtypeTransformer(BaseTransformer):
-    """
-    Transformer that converts a column to a different dtype.
+    """Transformer that converts a column to a different dtype.
 
     Example:
     ```python
     import numpy as np
     import pandas as pd
-    from sk_transformers.generic_transformer import DtypeTransformer
+    from sk_transformers import DtypeTransformer
 
     X = pd.DataFrame({"foo": [1, 2, 3], "bar": ["a", "a", "b"]})
     transformer = DtypeTransformer([("foo", np.float32), ("bar", "category")])
@@ -38,8 +37,8 @@ class DtypeTransformer(BaseTransformer):
         self.features = features
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        """
-        Transform the dataframe by converting the columns to the specified dtypes.
+        """Transform the dataframe by converting the columns to the specified
+        dtypes.
 
         Args:
             X (pandas.DataFrame): dataframe to transform.
@@ -47,7 +46,12 @@ class DtypeTransformer(BaseTransformer):
         Returns:
             pandas.DataFrame: Transformed dataframe.
         """
-        check_ready_to_transform(self, X, [feature[0] for feature in self.features])
+        check_ready_to_transform(
+            self,
+            X,
+            [feature[0] for feature in self.features],
+            force_all_finite="allow-nan",
+        )
 
         for (column, dtype) in self.features:
             X[column] = X[column].astype(dtype)
@@ -55,15 +59,17 @@ class DtypeTransformer(BaseTransformer):
 
 
 class AggregateTransformer(BaseTransformer):
-    """
-    This transformer uses Pandas `groupby` method and `aggregate` to apply function on a column grouped by another column.
-    Read more about Pandas [`aggregate`](https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.aggregate.html) method
-    to understand how to use function for aggregation. Other than Pandas function this transformer only support functions and string-names.
+    """This transformer uses Pandas `groupby` method and `aggregate` to apply
+    function on a column grouped by another column. Read more about Pandas [`ag
+    gregate`](https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.agg
+    regate.html) method to understand how to use function for aggregation.
+    Other than Pandas function this transformer only support functions and
+    string-names.
 
     Example:
     ```python
     import pandas as pd
-    from sk_transformers.generic_transformer import AggregateTransformer
+    from sk_transformers import AggregateTransformer
 
     X = pd.DataFrame(
         {
@@ -101,8 +107,8 @@ class AggregateTransformer(BaseTransformer):
         self.features = features
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        """
-        Creates new columns by using Pandas `groupby` method and `aggregate` to apply function on the column.
+        """Creates new columns by using Pandas `groupby` method and `aggregate`
+        to apply function on the column.
 
         Args:
             X (pd.DataFrame): Input dataframe.
@@ -142,16 +148,20 @@ class AggregateTransformer(BaseTransformer):
 
 
 class FunctionsTransformer(BaseTransformer):
-    """
-    This transformer is a plain wrapper around the [`sklearn.preprocessing.FunctionTransformer`](https://scikit-learn.org/stable/modules/generated/sklearn.preprocessing.FunctionTransformer.html).
-    Its main function is to apply multiple functions to different columns. Other than the scikit-learn transformer,
-    this transformer *does not* support the `inverse_func`, `accept_sparse`, `feature_names_out` and, `inv_kw_args` parameters.
+    """This transformer is a plain wrapper around the.
+
+    [`sklearn.preprocessing.FunctionTransformer`](https://scikit-learn.org/stab
+    le/modules/generated/sklearn.preprocessing.FunctionTransformer.html). Its
+    main function is to apply multiple functions to different columns. Other
+    than the scikit-learn transformer, this transformer *does not* support the
+    `inverse_func`, `accept_sparse`, `feature_names_out` and, `inv_kw_args`
+    parameters.
 
     Example:
     ```python
     import numpy as np
     import pandas as pd
-    from sk_transformers.generic_transformer import FunctionsTransformer
+    from sk_transformers import FunctionsTransformer
 
     X = pd.DataFrame({"foo": [1, 2, 3], "bar": [4, 5, 6]})
     transformer = FunctionsTransformer([("foo", np.log1p, None), ("bar", np.sqrt, None)])
@@ -177,8 +187,8 @@ class FunctionsTransformer(BaseTransformer):
         self.features = features
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        """
-        Applies the functions to the columns, and returns the dataframe with the modified columns.
+        """Applies the functions to the columns, and returns the dataframe with
+        the modified columns.
 
         Args:
             X (pandas.DataFrame): DataFrame containing the columns to apply the functions on.
@@ -198,14 +208,15 @@ class FunctionsTransformer(BaseTransformer):
 
 
 class MapTransformer(BaseTransformer):
-    """
-    This transformer iterates over all columns in the `features` list and applies the given callback to the column.
-    For this it uses the [`pandas.Series.map`](https://pandas.pydata.org/docs/reference/api/pandas.Series.map.html) method.
+    """This transformer iterates over all columns in the `features` list and
+    applies the given callback to the column. For this it uses the [`pandas.Ser
+    ies.map`](https://pandas.pydata.org/docs/reference/api/pandas.Series.map.ht
+    ml) method.
 
     Example:
     ```python
     import pandas as pd
-    from sk_transformers.generic_transformer import MapTransformer
+    from sk_transformers import MapTransformer
 
     X = pd.DataFrame({"foo": [1, 2, 3], "bar": [4, 5, 6]})
     transformer = MapTransformer([("foo", lambda x: x + 1)])
@@ -228,8 +239,7 @@ class MapTransformer(BaseTransformer):
         self.features = features
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        """
-        Applies the callback to the column.
+        """Applies the callback to the column.
 
         Args:
             X (pandas.DataFrame): Dataframe containing the the columns to apply the callback on.
@@ -248,13 +258,12 @@ class MapTransformer(BaseTransformer):
 
 
 class ColumnDropperTransformer(BaseTransformer):
-    """
-    Drops columns from a dataframe using Pandas `drop` method.
+    """Drops columns from a dataframe using Pandas `drop` method.
 
     Example:
     ```python
     import pandas as pd
-    from sk_transformers.generic_transformer import ColumnDropperTransformer
+    from sk_transformers import ColumnDropperTransformer
 
     X = pd.DataFrame({"foo": [1, 2, 3], "bar": [4, 5, 6]})
     transformer = ColumnDropperTransformer(["foo"])
@@ -276,8 +285,7 @@ class ColumnDropperTransformer(BaseTransformer):
         self.columns = columns
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        """
-        Returns the dataframe with the `columns` dropped.
+        """Returns the dataframe with the `columns` dropped.
 
         Args:
             X (pd.DataFrame): Dataframe to drop columns from.
@@ -285,17 +293,18 @@ class ColumnDropperTransformer(BaseTransformer):
         Returns:
             pd.DataFrame: Dataframe with columns dropped.
         """
-        X = check_ready_to_transform(self, X, self.columns)
+        X = check_ready_to_transform(self, X, self.columns, force_all_finite=False)
         return X.drop(self.columns, axis=1)
 
 
 class NaNTransformer(BaseTransformer):
-    """
-    Replace NaN values with a specified value. Internally Pandas [`fillna`](https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.fillna.html) method is used.
+    """Replace NaN values with a specified value. Internally Pandas [`fillna`](
+    https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.fillna.html)
+    method is used.
 
     Example:
     ```python
-    from sk_transformers.generic_transformer import NaNTransformer
+    from sk_transformers import NaNTransformer
     import pandas as pd
     import numpy as np
 
@@ -319,8 +328,7 @@ class NaNTransformer(BaseTransformer):
         self.features = features
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        """
-        Replace NaN values with a specified value.
+        """Replace NaN values with a specified value.
 
         Args:
             X (pandas.DataFrame): Dataframe to transform.
@@ -338,18 +346,18 @@ class NaNTransformer(BaseTransformer):
 
 
 class ValueIndicatorTransformer(BaseTransformer):
-    """
-    Adds a column to a dataframe indicating if a value is equal to a specified value.
-    The idea behind this method is, that it is often useful to know if a `NaN` value was
-    present in the original data and has been changed by some imputation step.
-    Sometimes the present of a `NaN` value is actually important information.
-    But obviously this method works with any kind of data.
+    """Adds a column to a dataframe indicating if a value is equal to a
+    specified value. The idea behind this method is, that it is often useful to
+    know if a `NaN` value was present in the original data and has been changed
+    by some imputation step. Sometimes the present of a `NaN` value is actually
+    important information. But obviously this method works with any kind of
+    data.
 
     `NaN`, `None` or `np.nan` are **Not** caught by this implementation.
 
     Example:
     ```python
-    from sk_transformers.generic_transformer import ValueIndicatorTransformer
+    from sk_transformers import ValueIndicatorTransformer
     import pandas as pd
 
     X = pd.DataFrame({"foo": [1, -999, 3], "bar": ["a", "-999", "c"]})
@@ -374,8 +382,8 @@ class ValueIndicatorTransformer(BaseTransformer):
         self.as_int = as_int
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        """
-        Add a column to a dataframe indicating if a value is equal to a specified value.
+        """Add a column to a dataframe indicating if a value is equal to a
+        specified value.
 
         Args:
             X (pandas.DataFrame): Dataframe to transform.
@@ -399,17 +407,15 @@ class ValueIndicatorTransformer(BaseTransformer):
 
 
 class QueryTransformer(BaseTransformer):
-    """
-    Applies a list of queries to a dataframe.
-    If it operates on a dataset used for supervised learning this transformer should
-    be applied on the dataframe containing `X` and `y`. So removing of columns by queries
-    also removes the corresponding `y` value.
-    Read more about queries [here](https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.query.html).
+    """Applies a list of queries to a dataframe. If it operates on a dataset
+    used for supervised learning this transformer should be applied on the
+    dataframe containing `X` and `y`. So removing of columns by queries also
+    removes the corresponding `y` value.
 
     Example:
     ```python
     import pandas as pd
-    from sk_transformers.generic_transformer import QueryTransformer
+    from sk_transformers import QueryTransformer
 
     X = pd.DataFrame({"foo": [1, 8, 3, 6, 5, 4, 7, 2]})
     transformer = QueryTransformer(["foo > 4"])
@@ -432,8 +438,7 @@ class QueryTransformer(BaseTransformer):
         self.queries = queries
 
     def transform(self, Xy: pd.DataFrame) -> pd.DataFrame:
-        """
-        Applies the list of queries to the dataframe.
+        """Applies the list of queries to the dataframe.
 
         Args:
             Xy (pd.DataFrame): Dataframe to apply the queries to. For also operating on the target column `y` - if needed.
@@ -450,16 +455,18 @@ class QueryTransformer(BaseTransformer):
 
 
 class ValueReplacerTransformer(BaseTransformer):
-    r"""
-    Uses Pandas `replace` method to replace values in a column. This transformer loops over the `features` and applies
-    `replace` to the according columns. If the column is not from type string but a valid regular expression is provided
-    the column will be temporarily changed to a string column and after the manipulation by `replace` changed back to its
-    original type. It may happen, that this type changing fails if the modified column is not compatible with its original type.
+    r"""Uses Pandas `replace` method to replace values in a column. This
+    transformer loops over the `features` and applies `replace` to the
+    according columns. If the column is not from type string but a valid
+    regular expression is provided the column will be temporarily changed to a
+    string column and after the manipulation by `replace` changed back to its
+    original type. It may happen, that this type changing fails if the modified
+    column is not compatible with its original type.
 
     Example:
     ```python
     import pandas as pd
-    from sk_transformers.generic_transformer import ValueReplacerTransformer
+    from sk_transformers import ValueReplacerTransformer
 
     X = pd.DataFrame(
         {"foo": ["0000-01-01", "2022/01/08", "bar", "1982-12-7", "28-09-2022"]}
@@ -496,8 +503,7 @@ class ValueReplacerTransformer(BaseTransformer):
         self.features = features
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        """
-        Replaces a value or regular expression with another value.
+        """Replaces a value or regular expression with another value.
 
         Args:
             X (pd.DataFrame): Dataframe containing the columns where values should be replaced.
@@ -538,15 +544,15 @@ class ValueReplacerTransformer(BaseTransformer):
 
 
 class LeftJoinTransformer(BaseTransformer):
-    """
-    Performs a database-style left-join using `pd.merge`. This transformer is suitable for
-    replacing values in a column of a dataframe by looking-up another `pd.DataFrame`
-    or `pd.Series`. Note that, the join is based on the index of the right dataframe.
+    """Performs a database-style left-join using `pd.merge`. This transformer
+    is suitable for replacing values in a column of a dataframe by looking-up
+    another `pd.DataFrame` or `pd.Series`. Note that, the join is based on the
+    index of the right dataframe.
 
     Example:
     ```python
     import pandas as pd
-    from sk_transformers.generic_transformer import LeftJoinTransformer
+    from sk_transformers import LeftJoinTransformer
 
     X = pd.DataFrame({"foo": ["A", "B", "C", "A", "C"]})
     lookup_df = pd.Series([1, 2, 3], index=["A", "B", "C"], name="values")
@@ -575,8 +581,8 @@ class LeftJoinTransformer(BaseTransformer):
         self.features = features
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        """
-        Perform a left-join on the given columns of a dataframe with another cooresponding dataframe.
+        """Perform a left-join on the given columns of a dataframe with another
+        cooresponding dataframe.
 
         Args:
             X (pd.DataFrame): Dataframe containing the columns to be joined on.
@@ -585,7 +591,12 @@ class LeftJoinTransformer(BaseTransformer):
             pd.DataFrame: Dataframe joined on the given columns.
         """
 
-        X = check_ready_to_transform(self, X, [feature[0] for feature in self.features])
+        X = check_ready_to_transform(
+            self,
+            X,
+            [feature[0] for feature in self.features],
+            force_all_finite="allow-nan",
+        )
 
         for (column, lookup_df) in self.features:
             lookup_df = LeftJoinTransformer.__prefix_df_column_names(lookup_df, column)
@@ -602,3 +613,60 @@ class LeftJoinTransformer(BaseTransformer):
         elif isinstance(df, pd.DataFrame):
             df.columns = [prefix + "_" + column for column in df.columns]
         return df
+
+
+class AllowedValuesTransformer(BaseTransformer):
+    """Replaces all values that are not in a list of allowed values with a
+    replacement value. This performs an complementary transformation to that of
+    the ValueReplacerTransformer. This is useful while lumping several minor
+    categories together by selecting them using a list of major categories.
+
+    Example:
+    ```python
+    import pandas as pd
+    from sk_transformers.generic_transformer import AllowedValuesTransformer
+
+    X = pd.DataFrame({"foo": ["a", "b", "c", "d", "e"]})
+    transformer = AllowedValuesTransformer([("foo", ["a", "b"], "other")])
+    transformer.fit_transform(X)
+    ```
+    ```
+         foo
+    0      a
+    1      b
+    2  other
+    3  other
+    4  other
+    ```
+
+    Args:
+        features (List[Tuple[str, List[Any], Any]]): List of tuples where
+            the first element is the column name,
+            the second element is the list of allowed values in the column, and
+            the third element is the value to replace disallowed values in the column.
+    """
+
+    def __init__(self, features: List[Tuple[str, List[Any], Any]]) -> None:
+        super().__init__()
+        self.features = features
+
+    def transform(self, X: pd.DataFrame) -> pd.DataFrame:
+        """Replaces values not in a list with another value.
+
+        Args:
+            X (pd.DataFrame): Dataframe containing the columns with values to be replaced.
+
+        Returns:
+            pd.DataFrame: Dataframe with replaced values.
+        """
+
+        X = check_ready_to_transform(
+            self,
+            X,
+            [feature[0] for feature in self.features],
+        )
+
+        for (column, allowed_values, replacement) in self.features:
+            X.loc[~X[column].isin(allowed_values), column] = replacement
+
+        return X
